#include <vtkCleanPolyData.h>
#include <vtkGeometryFilter.h>
#include <vtkSmartPointer.h>
#include <vtkSTLReader.h>
#include <vtkSTLWriter.h>

#include "vtkCleanPolyDataPolys.h"

int main(int argc, char* argv[])
{
  if (argc != 3)
  {
    std::cerr << "Required parameters: inputFileName outputFileName" << std::endl;
    return EXIT_FAILURE;
  }

  std::string inputFileName = argv[1];
  std::string outputFileName = argv[2];

  vtkSmartPointer<vtkSTLReader> reader =
    vtkSmartPointer<vtkSTLReader>::New();
  reader->SetFileName(inputFileName.c_str());

  // merge the duplicate points
  vtkSmartPointer<vtkCleanPolyData> cleaner =
    vtkSmartPointer<vtkCleanPolyData>::New();
  cleaner->SetInputConnection(reader->GetOutputPort());
  cleaner->GetToleranceIsAbsolute();
  cleaner->SetAbsoluteTolerance(0.01);
  cleaner->PointMergingOn();
  cleaner->Update();

  // merge the duplicate polys
  vtkSmartPointer<vtkCleanPolyDataPolys> remover =
    vtkSmartPointer<vtkCleanPolyDataPolys>::New();
  remover->SetInputData(cleaner->GetOutput());
  remover->Update();

  vtkSmartPointer<vtkSTLWriter> writer =
    vtkSmartPointer<vtkSTLWriter>::New();
  writer->SetFileName(outputFileName.c_str());
  writer->SetInputConnection(remover->GetOutputPort());
  writer->SetFileTypeToBinary();
  writer->Write();

  return EXIT_SUCCESS;
}
